package com.example.lectionsupabase.view.mainActivity.components

import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.ArrowBack
import androidx.compose.material.icons.filled.ArrowDropDown
import androidx.compose.material.icons.filled.ArrowForward
import androidx.compose.material3.Button
import androidx.compose.material3.ButtonDefaults
import androidx.compose.material3.DropdownMenu
import androidx.compose.material3.DropdownMenuItem
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.ExposedDropdownMenuBox
import androidx.compose.material3.Icon
import androidx.compose.material3.IconButton
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.RadioButton
import androidx.compose.material3.Slider
import androidx.compose.material3.SliderDefaults
import androidx.compose.material3.Text
import androidx.compose.material3.TextField
import androidx.compose.material3.TextFieldDefaults
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.layout.ContentScale
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.font.Font
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavHostController
import com.example.lectionsupabase.R


@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun Insert(navHost: NavHostController) {
    val options = listOf("Ресторан", "Концерт", "Выставка", "Фильм", "Лавочка")
    val selectedIndex = remember { mutableStateOf(0) } // Индекс выбранного элемента
    val montserratRegular = FontFamily(Font(R.font.mon_regular))
    val montserratSemiBold = FontFamily(Font(R.font.mon_semibold))
    val montserratMedium = FontFamily(Font(R.font.mon_medium))

    Column(
        modifier = Modifier
            .fillMaxSize()
            .padding(16.dp)
            .padding(top = 20.dp),
    ) {
        Row(
            modifier = Modifier
                .fillMaxWidth()
                .padding(vertical = 6.dp),
            verticalAlignment = Alignment.CenterVertically
        ) {
            // Стрелка влево
            IconButton(
                onClick = { navHost.navigate("Restaurants") },
            ) {
                Icon(
                    imageVector = Icons.Default.ArrowBack,
                    contentDescription = "Назад",
                    tint = Color.Black
                )
            }

            Text(
                text = "  Добавьте новое место",
                style = MaterialTheme.typography.headlineMedium,
                fontWeight = FontWeight.Bold,
                color = MaterialTheme.colorScheme.onBackground,
                textAlign = TextAlign.Center,
                fontSize = 20.sp,
                fontFamily = montserratSemiBold,
                modifier = Modifier.weight(1f)
            )

            // Стрелка с отступом
            IconButton(
                onClick = { navHost.navigate("Insert") },
                modifier = Modifier.padding(start = 8.dp)
            ) {
                Icon(
                    imageVector = Icons.Default.ArrowForward,
                    contentDescription = "Перейти к киноафише",
                    tint = Color.White
                )
            }
        }
        Spacer(modifier = Modifier.height(54.dp))
        // Текст над изображением
        Text(
            text = "Выберите на слайдере раздел места, \n которое вы хотите добавить",
            style = MaterialTheme.typography.bodyMedium,
            fontSize = 14.sp,
            fontFamily = montserratRegular,
            color = Color.Gray,
            textAlign = TextAlign.Center,
            modifier = Modifier
                .fillMaxWidth()
                .padding(vertical = 16.dp) // Отступы сверху и снизу
        )
        Spacer(modifier = Modifier.height(24.dp))
        // Картинка по центру
        Image(
            painter = painterResource(id = R.drawable.add), // Замените на свой ресурс
            contentDescription = "Изображение места",
            modifier = Modifier
                .size(220.dp)
                .clip(RoundedCornerShape(16.dp))
                .background(MaterialTheme.colorScheme.surface)
                .align(Alignment.CenterHorizontally), // Центрируем изображение
            contentScale = ContentScale.Crop
        )

        Spacer(modifier = Modifier.height(54.dp))

        Box(
            modifier = Modifier.fillMaxWidth(), // Занимает всю ширину
            contentAlignment = Alignment.Center // Центрируем содержимое
        ) {
            Slider(
                value = selectedIndex.value.toFloat(),
                onValueChange = { selectedIndex.value = it.toInt() },
                valueRange = 0f..(options.size - 1).toFloat(),
                steps = options.size - 2,
                modifier = Modifier.width(230.dp), // Устанавливаем ширину слайдера
                colors = SliderDefaults.colors(
                    thumbColor = Color(0xFFA3D5F1), // Цвет "пальца" слайдера
                    activeTrackColor = Color(0xFFA3D5F1), // Цвет активной части слайдера
                    inactiveTrackColor = Color(0xFFB0BEC5) // Цвет неактивной части слайдера
                )

            )

        }
        Text(
            text = "Выбранное место: ${options[selectedIndex.value]}",
            modifier = Modifier
                .padding(vertical = 6.dp) // Отступы сверху и снизу
                .padding(start = 70.dp), // Отступ слева
            fontFamily = montserratRegular,
            fontSize = 14.sp
        )
        // Отображение выбранного типа места


        Spacer(modifier = Modifier.height(64.dp))

        // Кнопка перехода к добавлению
        Button(
            onClick = {
                when (options[selectedIndex.value]) {
                    "Ресторан" -> navHost.navigate("InsertRestaurant")
                    "Концерт" -> navHost.navigate("InsertConcert")
                    "Выставка" -> navHost.navigate("InsertExhibition")
                    "Фильм" -> navHost.navigate("InsertMovie")
                    "Лавочка" -> navHost.navigate("InsertBench")
                }
            },
            modifier = Modifier
                .fillMaxWidth()
                .height(56.dp),
            shape = RoundedCornerShape(8.dp),
            colors = ButtonDefaults.buttonColors(
                containerColor = Color(0XFFA3D5F1), // Голубой фон
                contentColor = Color.White
            )
        ) {
            Text("Перейти к добавлению", fontSize = 15.sp, fontFamily = montserratMedium)
        }
    }
}